# Melee-YouTube-Uploader
A YouTube Uploader for my Melee recordings

A modified version of FRC-YouTube-Uploader for Super Smash Bros. Melee.

## To Do
* Automate creation of thumbnails
* Automate file picking
* Clean up the interface
* Update this README
